# Generated by Django 4.2.7 on 2026-01-04 11:22

from django.db import migrations, models
import django.db.models.deletion
import turbodrf.mixins


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('description', models.TextField(blank=True)),
            ],
            options={
                'verbose_name_plural': 'categories',
            },
            bases=(turbodrf.mixins.TurboDRFMixin, models.Model),
        ),
        migrations.CreateModel(
            name='CustomEndpointModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(turbodrf.mixins.TurboDRFMixin, models.Model),
        ),
        migrations.CreateModel(
            name='DisabledModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
            ],
            bases=(turbodrf.mixins.TurboDRFMixin, models.Model),
        ),
        migrations.CreateModel(
            name='NoTurboDRFModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
            ],
        ),
        migrations.CreateModel(
            name='RelatedModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100)),
                ('description', models.TextField(blank=True)),
            ],
            bases=(turbodrf.mixins.TurboDRFMixin, models.Model),
        ),
        migrations.CreateModel(
            name='SampleModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('description', models.TextField(blank=True)),
                ('price', models.DecimalField(decimal_places=2, max_digits=10)),
                ('quantity', models.IntegerField(default=0)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('published_date', models.DateField(blank=True, null=True)),
                ('is_active', models.BooleanField(default=True)),
                ('secret_field', models.CharField(blank=True, max_length=100)),
                ('related', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='test_models', to='test_app.relatedmodel')),
            ],
            options={
                'db_table': 'test_app_testmodel',
                'ordering': ['id'],
            },
            bases=(turbodrf.mixins.TurboDRFMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ArticleWithCategories',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('content', models.TextField(blank=True)),
                ('author', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='articles', to='test_app.relatedmodel')),
                ('categories', models.ManyToManyField(blank=True, related_name='articles', to='test_app.category')),
            ],
            bases=(turbodrf.mixins.TurboDRFMixin, models.Model),
        ),
    ]
